==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/VersionInfoFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class VersionInfoFluentImpl<A extends VersionInfoFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements VersionInfoFluent<A>{

    private String buildDate;
    private String compiler;
    private String gitCommit;
    private String gitTreeState;
    private String gitVersion;
    private String goVersion;
    private String major;
    private String minor;
    private String platform;

    public VersionInfoFluentImpl(){
    }
    public VersionInfoFluentImpl(VersionInfo instance){
            this.withBuildDate(instance.getBuildDate());

            this.withCompiler(instance.getCompiler());

            this.withGitCommit(instance.getGitCommit());

            this.withGitTreeState(instance.getGitTreeState());

            this.withGitVersion(instance.getGitVersion());

            this.withGoVersion(instance.getGoVersion());

            this.withMajor(instance.getMajor());

            this.withMinor(instance.getMinor());

            this.withPlatform(instance.getPlatform());

    }

    public String getBuildDate(){
            return this.buildDate;
    }

    public A withBuildDate(String buildDate){
            this.buildDate=buildDate; return (A) this;
    }

    public Boolean hasBuildDate(){
            return this.buildDate != null;
    }

    public String getCompiler(){
            return this.compiler;
    }

    public A withCompiler(String compiler){
            this.compiler=compiler; return (A) this;
    }

    public Boolean hasCompiler(){
            return this.compiler != null;
    }

    public String getGitCommit(){
            return this.gitCommit;
    }

    public A withGitCommit(String gitCommit){
            this.gitCommit=gitCommit; return (A) this;
    }

    public Boolean hasGitCommit(){
            return this.gitCommit != null;
    }

    public String getGitTreeState(){
            return this.gitTreeState;
    }

    public A withGitTreeState(String gitTreeState){
            this.gitTreeState=gitTreeState; return (A) this;
    }

    public Boolean hasGitTreeState(){
            return this.gitTreeState != null;
    }

    public String getGitVersion(){
            return this.gitVersion;
    }

    public A withGitVersion(String gitVersion){
            this.gitVersion=gitVersion; return (A) this;
    }

    public Boolean hasGitVersion(){
            return this.gitVersion != null;
    }

    public String getGoVersion(){
            return this.goVersion;
    }

    public A withGoVersion(String goVersion){
            this.goVersion=goVersion; return (A) this;
    }

    public Boolean hasGoVersion(){
            return this.goVersion != null;
    }

    public String getMajor(){
            return this.major;
    }

    public A withMajor(String major){
            this.major=major; return (A) this;
    }

    public Boolean hasMajor(){
            return this.major != null;
    }

    public String getMinor(){
            return this.minor;
    }

    public A withMinor(String minor){
            this.minor=minor; return (A) this;
    }

    public Boolean hasMinor(){
            return this.minor != null;
    }

    public String getPlatform(){
            return this.platform;
    }

    public A withPlatform(String platform){
            this.platform=platform; return (A) this;
    }

    public Boolean hasPlatform(){
            return this.platform != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            VersionInfoFluentImpl that = (VersionInfoFluentImpl) o;
            if (buildDate != null ? !buildDate.equals(that.buildDate) :that.buildDate != null) return false;
            if (compiler != null ? !compiler.equals(that.compiler) :that.compiler != null) return false;
            if (gitCommit != null ? !gitCommit.equals(that.gitCommit) :that.gitCommit != null) return false;
            if (gitTreeState != null ? !gitTreeState.equals(that.gitTreeState) :that.gitTreeState != null) return false;
            if (gitVersion != null ? !gitVersion.equals(that.gitVersion) :that.gitVersion != null) return false;
            if (goVersion != null ? !goVersion.equals(that.goVersion) :that.goVersion != null) return false;
            if (major != null ? !major.equals(that.major) :that.major != null) return false;
            if (minor != null ? !minor.equals(that.minor) :that.minor != null) return false;
            if (platform != null ? !platform.equals(that.platform) :that.platform != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/VersionInfoFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class VersionInfoFluentImpl<A extends VersionInfoFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements VersionInfoFluent<A>{

    private String buildDate;
    private String compiler;
    private String gitCommit;
    private String gitTreeState;
    private String gitVersion;
    private String goVersion;
    private String major;
    private String minor;
    private String platform;

    public VersionInfoFluentImpl(){
    }
    public VersionInfoFluentImpl(VersionInfo instance){
            this.withBuildDate(instance.getBuildDate());

            this.withCompiler(instance.getCompiler());

            this.withGitCommit(instance.getGitCommit());

            this.withGitTreeState(instance.getGitTreeState());

            this.withGitVersion(instance.getGitVersion());

            this.withGoVersion(instance.getGoVersion());

            this.withMajor(instance.getMajor());

            this.withMinor(instance.getMinor());

            this.withPlatform(instance.getPlatform());

    }

    public String getBuildDate(){
            return this.buildDate;
    }

    public A withBuildDate(String buildDate){
            this.buildDate=buildDate; return (A) this;
    }

    public Boolean hasBuildDate(){
            return this.buildDate != null;
    }

    public A withNewBuildDate(String arg1){
            return (A)withBuildDate(new String(arg1));
    }

    public A withNewBuildDate(StringBuilder arg1){
            return (A)withBuildDate(new String(arg1));
    }

    public A withNewBuildDate(StringBuffer arg1){
            return (A)withBuildDate(new String(arg1));
    }

    public String getCompiler(){
            return this.compiler;
    }

    public A withCompiler(String compiler){
            this.compiler=compiler; return (A) this;
    }

    public Boolean hasCompiler(){
            return this.compiler != null;
    }

    public A withNewCompiler(String arg1){
            return (A)withCompiler(new String(arg1));
    }

    public A withNewCompiler(StringBuilder arg1){
            return (A)withCompiler(new String(arg1));
    }

    public A withNewCompiler(StringBuffer arg1){
            return (A)withCompiler(new String(arg1));
    }

    public String getGitCommit(){
            return this.gitCommit;
    }

    public A withGitCommit(String gitCommit){
            this.gitCommit=gitCommit; return (A) this;
    }

    public Boolean hasGitCommit(){
            return this.gitCommit != null;
    }

    public A withNewGitCommit(String arg1){
            return (A)withGitCommit(new String(arg1));
    }

    public A withNewGitCommit(StringBuilder arg1){
            return (A)withGitCommit(new String(arg1));
    }

    public A withNewGitCommit(StringBuffer arg1){
            return (A)withGitCommit(new String(arg1));
    }

    public String getGitTreeState(){
            return this.gitTreeState;
    }

    public A withGitTreeState(String gitTreeState){
            this.gitTreeState=gitTreeState; return (A) this;
    }

    public Boolean hasGitTreeState(){
            return this.gitTreeState != null;
    }

    public A withNewGitTreeState(String arg1){
            return (A)withGitTreeState(new String(arg1));
    }

    public A withNewGitTreeState(StringBuilder arg1){
            return (A)withGitTreeState(new String(arg1));
    }

    public A withNewGitTreeState(StringBuffer arg1){
            return (A)withGitTreeState(new String(arg1));
    }

    public String getGitVersion(){
            return this.gitVersion;
    }

    public A withGitVersion(String gitVersion){
            this.gitVersion=gitVersion; return (A) this;
    }

    public Boolean hasGitVersion(){
            return this.gitVersion != null;
    }

    public A withNewGitVersion(String arg1){
            return (A)withGitVersion(new String(arg1));
    }

    public A withNewGitVersion(StringBuilder arg1){
            return (A)withGitVersion(new String(arg1));
    }

    public A withNewGitVersion(StringBuffer arg1){
            return (A)withGitVersion(new String(arg1));
    }

    public String getGoVersion(){
            return this.goVersion;
    }

    public A withGoVersion(String goVersion){
            this.goVersion=goVersion; return (A) this;
    }

    public Boolean hasGoVersion(){
            return this.goVersion != null;
    }

    public A withNewGoVersion(String arg1){
            return (A)withGoVersion(new String(arg1));
    }

    public A withNewGoVersion(StringBuilder arg1){
            return (A)withGoVersion(new String(arg1));
    }

    public A withNewGoVersion(StringBuffer arg1){
            return (A)withGoVersion(new String(arg1));
    }

    public String getMajor(){
            return this.major;
    }

    public A withMajor(String major){
            this.major=major; return (A) this;
    }

    public Boolean hasMajor(){
            return this.major != null;
    }

    public A withNewMajor(String arg1){
            return (A)withMajor(new String(arg1));
    }

    public A withNewMajor(StringBuilder arg1){
            return (A)withMajor(new String(arg1));
    }

    public A withNewMajor(StringBuffer arg1){
            return (A)withMajor(new String(arg1));
    }

    public String getMinor(){
            return this.minor;
    }

    public A withMinor(String minor){
            this.minor=minor; return (A) this;
    }

    public Boolean hasMinor(){
            return this.minor != null;
    }

    public A withNewMinor(String arg1){
            return (A)withMinor(new String(arg1));
    }

    public A withNewMinor(StringBuilder arg1){
            return (A)withMinor(new String(arg1));
    }

    public A withNewMinor(StringBuffer arg1){
            return (A)withMinor(new String(arg1));
    }

    public String getPlatform(){
            return this.platform;
    }

    public A withPlatform(String platform){
            this.platform=platform; return (A) this;
    }

    public Boolean hasPlatform(){
            return this.platform != null;
    }

    public A withNewPlatform(String arg1){
            return (A)withPlatform(new String(arg1));
    }

    public A withNewPlatform(StringBuilder arg1){
            return (A)withPlatform(new String(arg1));
    }

    public A withNewPlatform(StringBuffer arg1){
            return (A)withPlatform(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            VersionInfoFluentImpl that = (VersionInfoFluentImpl) o;
            if (buildDate != null ? !buildDate.equals(that.buildDate) :that.buildDate != null) return false;
            if (compiler != null ? !compiler.equals(that.compiler) :that.compiler != null) return false;
            if (gitCommit != null ? !gitCommit.equals(that.gitCommit) :that.gitCommit != null) return false;
            if (gitTreeState != null ? !gitTreeState.equals(that.gitTreeState) :that.gitTreeState != null) return false;
            if (gitVersion != null ? !gitVersion.equals(that.gitVersion) :that.gitVersion != null) return false;
            if (goVersion != null ? !goVersion.equals(that.goVersion) :that.goVersion != null) return false;
            if (major != null ? !major.equals(that.major) :that.major != null) return false;
            if (minor != null ? !minor.equals(that.minor) :that.minor != null) return false;
            if (platform != null ? !platform.equals(that.platform) :that.platform != null) return false;
            return true;
    }




}
